@@ -45,3 +45,7 @@ class RtpStream(object):
                 rgb = cv2.cvtColor(bgr, cv2.COLOR_BGR2RGB)
                 cuda_mem = jetson.utils.cudaFromNumpy(rgb)
                 self.rtp.Render(cuda_mem)
+
+
+def bgr8_to_jpeg(value):
+    return bytes(cv2.imencode('.jpg', value)[1])
